.. _edit-gff:

edit-gff - GFF Viewer and Editor
================================

Overview
--------

.. automodule:: mgkit.workflow.edit_gff


Options
-------

.. click:: mgkit.workflow.edit_gff:main
   :prog: edit-gff
   :show-nested:
